@@ -23,40 +23,22 @@
 #define EXTRACT_GPUINFO_H_
 
 #include "nvtop/extract_gpuinfo_common.h"
-#include "nvtop/extract_gpuinfo_nvidia.h"
 
 #include <stdbool.h>
 
-enum gpuinfo_gputype {
-  gpuinfo_type_nvidia_proprietary,
-};
+bool gpuinfo_init_info_extraction(unsigned *total_dev_count, struct list_head *devices);
 
-typedef struct gpu_info_struct {
-  enum gpuinfo_gputype gpu_type;
-  union {
-    gpuinfo_nvidia_device_handle nvidia_gpuhandle;
-  };
-  gpuinfo_static_info static_info;
-  gpuinfo_dynamic_info dynamic_info;
-  unsigned processes_count;
-  gpu_process *processes;
-  union {
-    gpuinfo_nvidia_internal_data nvidia_internal;
-  };
-} gpu_info;
+bool gpuinfo_shutdown_info_extraction(struct list_head *devices);
 
-bool gpuinfo_init_info_extraction(uint64_t mask_nvidia, unsigned *devices_count, gpu_info **devices);
+bool gpuinfo_populate_static_infos(struct list_head *devices);
 
-bool gpuinfo_shutdown_info_extraction(unsigned device_count,
-                                      gpu_info *devices);
+bool gpuinfo_refresh_dynamic_info(struct list_head *devices);
 
-bool gpuinfo_populate_static_infos(unsigned device_count, gpu_info *devices);
+bool gpuinfo_fix_dynamic_info_from_process_info(struct list_head *devices);
 
-bool gpuinfo_refresh_dynamic_info(unsigned device_count, gpu_info *devices);
+bool gpuinfo_refresh_processes(struct list_head *devices);
 
-bool gpuinfo_refresh_processes(unsigned device_count, gpu_info *devices);
-
-void gpuinfo_clean(unsigned device_count, gpu_info *devices);
+void gpuinfo_clean(struct list_head *devices);
 
 void gpuinfo_clear_cache(void);
 
