@@ -3,6 +3,7 @@
  * Copyright (C) 2018 Genesis Cloud Ltd.
  * Copyright (C) 2022 YiFei Zhu <zhuyifei1999@gmail.com>
  * Copyright (C) 2022 Maxime Schmitt <maxime.schmitt91@gmail.com>
+ * Copyright (C) 2023 Advanced Micro Devices, Inc. All rights reserved.
  *
  * This file is part of Nvtop and adapted from radeontop.
  *
@@ -51,6 +52,9 @@
 #include <uthash.h>
 #include <xf86drm.h>
 
+// extern
+const char *amdgpu_parse_marketing_name(struct amdgpu_gpu_info *info);
+
 // Local function pointers to DRM interface
 static typeof(drmGetDevices) *_drmGetDevices;
 static typeof(drmGetDevices2) *_drmGetDevices2;
@@ -95,6 +99,7 @@ enum amdgpu_process_info_cache_valid {
 struct __attribute__((__packed__)) unique_cache_id {
   unsigned client_id;
   pid_t pid;
+  char *pdev;
 };
 
 struct amdgpu_process_info_cache {
@@ -455,7 +460,7 @@ static bool gpuinfo_amdgpu_get_device_handles(struct list_head *devices, unsigne
       gpu_infos[amdgpu_count].fd = fd;
       gpu_infos[amdgpu_count].base.vendor = &gpu_vendor_amdgpu;
 
-      snprintf(gpu_infos[*count].base.pdev, PDEV_LEN - 1, "%04x:%02x:%02x.%d", devs[i]->businfo.pci->domain,
+      snprintf(gpu_infos[amdgpu_count].base.pdev, PDEV_LEN - 1, "%04x:%02x:%02x.%d", devs[i]->businfo.pci->domain,
                devs[i]->businfo.pci->bus, devs[i]->businfo.pci->dev, devs[i]->businfo.pci->func);
       initDeviceSysfsPaths(&gpu_infos[amdgpu_count]);
       list_add_tail(&gpu_infos[amdgpu_count].base.list, devices);
@@ -516,6 +521,17 @@ static void gpuinfo_amdgpu_populate_static_info(struct gpu_info *_gpu_info) {
   if (libdrm_amdgpu_handle && _amdgpu_query_gpu_info)
     info_query_success = !_amdgpu_query_gpu_info(gpu_info->amdgpu_device, &info);
 
+  /* check name again.
+   * the previous name is from libdrm, which may not be the latest version.
+   * it may not contain latest AMD GPU types/names
+   *
+   * the libdrm is from vendor, Linux and a Linux distribution.
+   * It may take long time for a Linux distribution to get latest GPU info.
+   * here a GPU IDS is maintained, which allows to support GPU info faster. */
+  if (!name) {
+    name = amdgpu_parse_marketing_name(&info);
+  }
+
   static_info->device_name[MAX_DEVICE_NAME - 1] = '\0';
   if (name && strlen(name)) {
     strncpy(static_info->device_name, name, MAX_DEVICE_NAME - 1);
@@ -736,8 +752,9 @@ static void gpuinfo_amdgpu_refresh_dynamic_info(struct gpu_info *_gpu_info) {
     int NreadPatterns =
         rewindAndReadPattern(gpu_info->PCIeBW, "%" SCNu64 " %" SCNu64 " %i", &received, &transmitted, &maxPayloadSize);
     if (NreadPatterns == 3) {
-      received *= maxPayloadSize;
-      transmitted *= maxPayloadSize;
+      // Compute received/transmitter in KiB
+      received *= maxPayloadSize / 1024;
+      transmitted *= maxPayloadSize / 1024;
       SET_GPUINFO_DYNAMIC(dynamic_info, pcie_rx, received);
       SET_GPUINFO_DYNAMIC(dynamic_info, pcie_tx, transmitted);
     }
@@ -891,7 +908,7 @@ static bool parse_drm_fdinfo_amd(struct gpu_info *info, FILE *fdinfo_file, struc
   // busy percentage since the last measurement.
   if (client_id_set) {
     struct amdgpu_process_info_cache *cache_entry;
-    struct unique_cache_id ucid = {.client_id = cid, .pid = process_info->pid};
+    struct unique_cache_id ucid = {.client_id = cid, .pid = process_info->pid, .pdev = gpu_info->base.pdev};
     HASH_FIND_CLIENT(gpu_info->last_update_process_cache, &ucid, cache_entry);
     if (cache_entry) {
       uint64_t time_elapsed = nvtop_difftime_u64(cache_entry->last_measurement_tstamp, current_time);
@@ -937,6 +954,7 @@ static bool parse_drm_fdinfo_amd(struct gpu_info *info, FILE *fdinfo_file, struc
         goto parse_fdinfo_exit;
       cache_entry->client_id.client_id = cid;
       cache_entry->client_id.pid = process_info->pid;
+      cache_entry->client_id.pdev = gpu_info->base.pdev;
     }
 
 #ifndef NDEBUG
